@@ -660,6 +660,51 @@ plot.ebirdst_ppms_ts <- function(x,
 
 # internal ----
 
+#' Calculate MCC and F1 score
+#'
+#' Given binary observed and predicted response, estimate Matthews correlation
+#' coefficient (MCC) and the F1 score.
+#'
+#' @param observed logical or 0/1; the observed binary response.
+#' @param predicted logical or 0/1; the predicted binary response. This will typically
+#'   need to be generated by applying a threshold to the continuous predicted
+#'   response.
+#'
+#' @return A list with two elements: `mcc` and `f1`.
+#' @export
+#' @examples
+#' obs <- c(rep(1L, 1000L), rep(0L, 10000L))
+#' pred <- c(rbeta(300L, 12, 2), rbeta(700L, 3, 4), rbeta(10000L, 2, 3))
+#' calculate_mcc_f1(obs > 0, pred > 0.5)
+calculate_mcc_f1 <- function(observed, predicted) {
+  if (!requireNamespace("PresenceAbsence", quietly = TRUE)) {
+    stop("Package 'PresenceAbsence' must be installed to use this function.")
+  }
+  stopifnot(is.logical(observed) || all(observed %in% c(0L, 1L)),
+            is.logical(predicted) || all(predicted %in% c(0L, 1L)),
+            length(observed) == length(predicted))
+
+  # confusion matrix
+  obs_pred <- data.frame(blank = "x",
+                         obs = as.numeric(observed),
+                         pred = as.numeric(predicted))
+  cmx <- PresenceAbsence::cmx(obs_pred, na.rm = TRUE)
+  tp <- cmx[1, 1]
+  fp <- cmx[1, 2]
+  fn <- cmx[2, 1]
+  tn <- cmx[2, 2]
+
+  # f1 score
+  p_pat <- tp / (tp + fp)
+  r_pat <- tp / (tp + fn)
+  f1 <- 2 * ((p_pat * r_pat) / (p_pat + r_pat))
+
+  # mcc
+  mcc_denom <- sqrt((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn))
+  mcc <- ((tp * tn) - (fp * fn)) / mcc_denom
+  return(list(f1 = f1, mcc = mcc))
+}
+
 #' Poisson deviance
 #'
 #' @param obs numeric; observed values.
